@@ -1,6 +1,6 @@
 package Markdent::Simple::Fragment;
 {
-  $Markdent::Simple::Fragment::VERSION = '0.21';
+  $Markdent::Simple::Fragment::VERSION = '0.22';
 }
 
 use strict;
@@ -9,33 +9,31 @@ use namespace::autoclean;
 
 use Markdent::Handler::HTMLStream::Fragment;
 use Markdent::Parser;
-use Markdent::Types qw( Str );
+use Markdent::Types qw( ArrayRef Str );
 use MooseX::Params::Validate qw( validated_list );
 
 use Moose;
 use MooseX::StrictConstructor;
 
+with 'Markdent::Role::Simple';
+
 sub markdown_to_html {
     my $self = shift;
-    my ( $dialect, $markdown ) = validated_list(
+    my ( $dialects, $markdown ) = validated_list(
         \@_,
-        dialect  => { isa => Str, default => 'Standard' },
+        dialects => {
+            isa => Str | ( ArrayRef [Str] ), default => [],
+        },
         markdown => { isa => Str },
     );
 
-    my $capture = q{};
-    open my $fh, '>', \$capture
-        or die $!;
+    my $handler_class = 'Markdent::Handler::HTMLStream::Fragment';
 
-    my $handler
-        = Markdent::Handler::HTMLStream::Fragment->new( output => $fh );
-
-    my $parser
-        = Markdent::Parser->new( dialect => $dialect, handler => $handler );
-
-    $parser->parse( markdown => $markdown );
-
-    return $capture;
+    return $self->_parse_markdown(
+        $markdown,
+        $dialects,
+        $handler_class,
+    );
 }
 
 1;
@@ -52,7 +50,7 @@ Markdent::Simple::Fragment - Convert Markdown to an HTML Fragment
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
@@ -81,6 +79,10 @@ This method turns Markdown into HTML.
 
 You can also provide an optional "dialect" parameter.
 
+=head1 ROLES
+
+This class does the L<Markdent::Role::Simple> role.
+
 =head1 BUGS
 
 See L<Markdent> for bug reporting details.
@@ -91,7 +93,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Dave Rolsky.
+This software is copyright (c) 2012 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
